@@ -26,7 +26,6 @@
 #include <queue>
 #include <stack>
 #include <QHash>
-#include <QSet>
 #include <unordered_set>
 #include <unordered_map>
 
@@ -51,7 +50,10 @@ namespace std                                               \
     };                                                      \
 }
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
+// Qt >= 5.14 already has std::hash for QBitArray
 q_Hash_to_tr1_hash(QBitArray)
+#endif
 
 namespace KDevPG
 {
